# Gencove Python API and CLI

## Quick install ##
`pip install gencove`

## Documentation ##
Main documentation can be found here: [http://docs.gencove.com](http://docs.gencove.com)


## Local Development

```bash
pip install -e .
```

Work as needed, package is installed in editable mode.
